<?php

namespace Chemical\Export\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Chemical\Export\Http\Requests\ExportRequest;
use Chemical\Export\Interfaces\ExportRepositoryInterface;
use Chemical\Export\Models\Export;

/**
 * Resource controller class for export.
 */
class ExportResourceController extends BaseController
{

    /**
     * Initialize export resource controller.
     *
     * @param type ExportRepositoryInterface $export
     *
     * @return null
     */
    public function __construct(ExportRepositoryInterface $export)
    {
        parent::__construct();
        $this->repository = $export;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Chemical\Export\Repositories\Criteria\ExportResourceCriteria::class);
    }

    /**
     * Display a list of export.
     *
     * @return Response
     */
    public function index(ExportRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Chemical\Export\Repositories\Presenter\ExportPresenter::class)
                ->$function();
        }

        $exports = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('export::export.names'))
            ->view('export::export.index', true)
            ->data(compact('exports', 'view'))
            ->output();
    }

    /**
     * Display export.
     *
     * @param Request $request
     * @param Model   $export
     *
     * @return Response
     */
    public function show(ExportRequest $request, Export $export)
    {

        if ($export->exists) {
            $view = 'export::export.show';
        } else {
            $view = 'export::export.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('export::export.name'))
            ->data(compact('export'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new export.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ExportRequest $request)
    {

        $export = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('export::export.name')) 
            ->view('export::export.create', true) 
            ->data(compact('export'))
            ->output();
    }

    /**
     * Create new export.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ExportRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $export                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('export::export.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('export/export/' . $export->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/export/export'))
                ->redirect();
        }

    }

    /**
     * Show export for editing.
     *
     * @param Request $request
     * @param Model   $export
     *
     * @return Response
     */
    public function edit(ExportRequest $request, Export $export)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('export::export.name'))
            ->view('export::export.edit', true)
            ->data(compact('export'))
            ->output();
    }

    /**
     * Update the export.
     *
     * @param Request $request
     * @param Model   $export
     *
     * @return Response
     */
    public function update(ExportRequest $request, Export $export)
    {
        try {
            $attributes = $request->all();

            $export->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('export::export.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('export/export/' . $export->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('export/export/' . $export->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the export.
     *
     * @param Model   $export
     *
     * @return Response
     */
    public function destroy(ExportRequest $request, Export $export)
    {
        try {

            $export->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('export::export.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('export/export/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('export/export/' . $export->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple export.
     *
     * @param Model   $export
     *
     * @return Response
     */
    public function delete(ExportRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('export::export.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('export/export'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/export/export'))
                ->redirect();
        }

    }

    /**
     * Restore deleted exports.
     *
     * @param Model   $export
     *
     * @return Response
     */
    public function restore(ExportRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('export::export.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/export/export'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/export/export/'))
                ->redirect();
        }

    }

}
